@@ -2,18 +2,13 @@ import os
 import json
 from typing import List
 import six
-from time import time
-
-try:
-    import cPickle as pickle
-except ImportError:  # pragma: nocover
-    import pickle
+import traceback
+from typing import Dict
 
 from uhashring import HashRing
 from apscheduler.jobstores.redis import RedisJobStore
 from apscheduler.schedulers.background import BackgroundScheduler
-from apscheduler.util import ref_to_obj, undefined, datetime_to_utc_timestamp
-from apscheduler.job import Job
+from apscheduler.util import ref_to_obj
 
 from fastapi_crawler_scheduler.service.dbRedisHelper import DbRedisHelper, standard_time
 
@@ -37,7 +32,6 @@ def format_params(params) -> dict:
             del params[key]
         except KeyError:
             pass
-
     return params
 
 
@@ -50,9 +44,6 @@ class BaseScheduler(object):
             uuid_number: str,
             project_name: str,
             redis_job_store: RedisJobStore,
-            misfire_grace_time: int = 10,
-            coalesce: bool = True,
-            max_instances: int = 1,
 
     ) -> None:
         self.uuid_number = uuid_number
@@ -61,9 +52,6 @@ class BaseScheduler(object):
         self.scheduler = scheduler
         self.process_id_list = []
         self.redis_job_store = redis_job_store
-        self.misfire_grace_time = misfire_grace_time
-        self.coalesce = coalesce
-        self.max_instances = max_instances
 
     def scheduler_add_job(
             self,
@@ -72,50 +60,22 @@ class BaseScheduler(object):
         try:
             func = ref_to_obj(crawler_info.get('func'))
         except Exception as e:
-            print(e)
-            print("函数有问题")
+            print(f"scheduler_add_job   函数错误 ：{e}")
+            print(traceback.format_exc())
             return
         interval = crawler_info.get('interval')
         trigger = crawler_info.get('trigger')
         job_id = crawler_info.get('job_id')
-        # if self.redis_job_store.redis.hexists(self.redis_job_store.jobs_key, job_id):
-        #     self.redis_job_store.remove_job(job_id=job_id)
-        crawler_info = format_params(params=crawler_info)
-        job_kwargs = {
-            'trigger': self.scheduler._create_trigger(trigger, dict(seconds=interval)),
-            'executor': 'default',
-            'func': func,
-            'args': (),
-            'kwargs': crawler_info,
-            'id': job_id,
-            'name': None,
-            'misfire_grace_time': self.misfire_grace_time,
-            'coalesce': self.coalesce,
-            'max_instances': self.max_instances,
-            'next_run_time': undefined
-        }
-        job_kwargs = dict((key, value) for key, value in six.iteritems(job_kwargs) if value is not undefined)
-        job = Job(self, **job_kwargs)
-        if self.redis_job_store.redis.hexists(self.redis_job_store.jobs_key, job.id):
+        if self.redis_job_store.redis.hexists(self.redis_job_store.jobs_key, job_id):
             self.redis_job_store.remove_job(job_id=job_id)
-
-        with self.redis_job_store.redis.pipeline() as pipe:
-            pipe.multi()
-            pipe.hset(self.redis_job_store.jobs_key, job.id, pickle.dumps(job.__getstate__(),
-                                                                          self.redis_job_store.pickle_protocol))
-            if job.next_run_time:
-                pipe.zadd(self.redis_job_store.run_times_key,
-                          {job.id: datetime_to_utc_timestamp(job.next_run_time)})
-
-            pipe.execute()
-
-        # self.scheduler.add_job(
-        #     func,
-        #     id=job_id,
-        #     trigger=trigger,
-        #     kwargs=crawler_info,
-        #     seconds=interval,
-        # )
+        crawler_info = format_params(params=crawler_info)
+        self.scheduler.add_job(
+            func,
+            id=job_id,
+            trigger=trigger,
+            kwargs=crawler_info,
+            seconds=interval,
+        )
 
     def check_process(self) -> None:
         self.redis_db.process_acquire(f'{self.project_name}:node:{self.uuid_number}:{os.getpid()}')
@@ -208,6 +168,8 @@ class BaseScheduler(object):
         insert_task = self.redis_db.get_insert_task()
         insert_task_key_list = div_list(tem_lists=insert_task)
         for key_list in insert_task_key_list:
+            if len(key_list) == 0:
+                return
             for insert_key, insert_value in self.redis_db.get_tasks(keys=key_list).items():
                 try:
                     if insert_value is None:
@@ -221,9 +183,11 @@ class BaseScheduler(object):
                         self.scheduler_add_job(**insert_value)
                         self.redis_db.delete_key(lock_name=insert_key)
                     else:
+                        pass
                         self.process_check_count(process_id=process_id, check_key=insert_key)
                 except Exception as e:
-                    print(e)
+                    print(f"check_insert_task 函数 错误 ：{e}")
+                    print(traceback.format_exc())
 
     def check_update_task(self) -> None:
         # 处理 update_task
@@ -245,11 +209,10 @@ class BaseScheduler(object):
                     else:
                         self.process_check_count(process_id=process_id, check_key=update_key)
                 except Exception as e:
-                    print(e)
+                    print(f"check_update_task 函数 错误 ：{e}")
+                    print(traceback.format_exc())
 
     def check_delete_task(self) -> None:
-
-        # 处理 delete_task
         delete_task = self.redis_db.get_delete_task()
         delete_task_key_list = div_list(tem_lists=delete_task)
         for key_list in delete_task_key_list:
@@ -269,16 +232,17 @@ class BaseScheduler(object):
                     else:
                         self.process_check_count(process_id=process_id, check_key=delete_key)
                 except Exception as e:
-                    print(e)
+                    print(f"check_delete_task 函数 错误 ：{e}")
+                    print(traceback.format_exc())
 
-    def insert_task(self, crawler_info: dict) -> dict:
+    def insert_task(self, crawler_info: Dict) -> dict:
         crawler_info['operation'] = 'insert'
         crawler_info['is_change'] = 1
         self.redis_db.string_set(f'{self.project_name}:backend:{crawler_info.get("job_id")}',
                                  json.dumps(crawler_info, ensure_ascii=False))
         return {"is_ok": 1, "reason": f"insert success {crawler_info['job_id']}"}
 
-    def update_task(self, crawler_info: dict) -> dict:
+    def update_task(self, crawler_info: Dict) -> dict:
         crawler_info['operation'] = 'update'
         crawler_info['is_change'] = 1
         self.redis_db.string_set(f'{self.project_name}:backend:{crawler_info.get("job_id")}',
@@ -337,22 +301,16 @@ class BaseScheduler(object):
                         pass
                         with self.redis_job_store.redis.pipeline() as pipe:
                             pipe.hdel(stores_job_key, job_id)
+                            pipe.execute()
+                        with self.redis_job_store.redis.pipeline() as pipe:
                             pipe.zrem(stores_job_run_times_key, job_id)
                             pipe.execute()
                     continue
-                # print("*************************************************************")
-                # print(f"job {job}")
-                # print(f"belongs_to_process_id {belongs_to_process_id}")
-                # print("----------------------------------------------------------------")
 
     def run(self) -> None:
-        # start_time = time()
         self.check_backend_task()
         self.check_all_task()
         self.check_insert_task()
         self.check_update_task()
         self.check_delete_task()
         self.sync_scheduler_job_to_redis()
-        # print("*************************************")
-        # end_time = time()
-        # print(f"耗时： {end_time - start_time} seconds since")
